# -*- coding: utf-8 -*-
###############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (C) 2012-Today Julius Network Solutions SARL <contact@julius.fr>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
###############################################################################

from openerp.osv import fields, orm


class hr_employee(orm.Model):
    _inherit = "hr.employee"
    _columns = {
                'street': fields.related('address_home_id', 'street',
                                         string='Street', type='char',
                                         size=128),
                'street2': fields.related('address_home_id', 'street2',
                                          string='Street2', type='char',
                                          size=128),
                'zip': fields.related('address_home_id', 'zip', string='Zip',
                                      type='char', size=24),
                'city': fields.related('address_home_id', 'city',
                                       string='City', type='char', size=128),
                'state_id': fields.related('address_home_id', 'state_id',
                                           string='State', type='many2one',
                                           relation='res.country.state'),
                'home_country_id': fields.related('address_home_id', 'country_id',
                                                  string='Country', type='many2one',
                                                  relation='res.country'),
                'email': fields.related('address_home_id', 'email',
                                        string='E-mail', type='char',
                                        size=128),
                'phone': fields.related('address_home_id', 'phone',
                                        string='Phone', type='char', size=64),
                'fax': fields.related('address_home_id', 'fax',
                                      string='Fax', type='char', size=64),
                'mobile': fields.related('address_home_id', 'mobile',
                                         string='Mobile', type='char',
                                         size=64),
                'title': fields.related('address_home_id', 'title',
                                        string="Title", type="many2one",
                                        relation='res.partner.title')
                }

    def _get_default_partner_values(self, cr, uid, vals, type='create',
                                    context=None):
        """
        Get the default values to create automatically the address_home_id
        """
        if context is None:
            context = {}
        partner_vals = {
                        'employee': True,
                        }
        if type == 'create':
            partner_vals.\
                update({
                        'customer': False,
                        'supplier': False,
                        'active': vals.get('active', True),
                        'function': vals.get('function', False),
                        'street': vals.get('street', False),
                        'street2': vals.get('street2', False),
                        'zip': vals.get('zip', False),
                        'city': vals.get('city', False),
                        'state_id': vals.get('state_id', False),
                        'country_id': vals.get('home_country_id', False),
                        'email': vals.get('email', False),
                        'phone': vals.get('phone', False),
                        'fax': vals.get('fax', False),
                        'mobile': vals.get('mobile', False),
                        'title': vals.get('title', False),
                        })
            if vals.get('name'):
                partner_vals.update({'name': vals.get('name')})
        elif type == 'write':
            for field in ['active', 'function', 'street',
                          'street2', 'zip', 'city',
                          'state_id', 'home_country_id', 'email',
                          'phone', 'fax', 'mobile', 'title']:
                if field in vals.keys():
                    if field == 'home_country_id':
                        partner_vals.update({'country_id': vals.get(field)})
                    else:
                        partner_vals.update({field: vals.get(field)})
        return partner_vals

    def create(self, cr, uid, vals, context=None):
        if context is None:
            context = {}
        partner_obj = self.pool.get('res.partner')
        partner_vals = self.\
            _get_default_partner_values(cr, uid, vals, context=context)
        if not vals.get('address_home_id', False):
            partner_id = partner_obj.create(cr, uid, partner_vals,
                                            context=context)
            partner_vals.update({
                                 'name': vals.get('name', False) or '',
                                 })
            vals.update({'address_home_id': partner_id})
        else:
            partner_obj.\
                write(cr, uid, vals.get('address_home_id'), partner_vals,
                      context=context)
        return super(hr_employee, self).create(cr, uid, vals, context=context)

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
